# desc.R
# 8/26/04
# Computes descriptive stats, including back of the env. estimates for Media Bias paper.


########################## Clear memory ##############################
rm(list=ls())

################# Define constants and set parmeters #################

# Center defined by midpoint of (i) senate ave, weighted by population and
# (ii) House ave.  Both computed with phantom D.C. legislators with highest
# possible lib score.  Both averaged over the period 1995-99.
Center = 50.06

CutPoint = 50.06
# Used for Back of the Envelope calculations

# Omit observations in which the legislator or reporter criticized the think tank?
OmitCrits = T

# Omit obseravtions in which the legislator or reporter gave the th. t. an ideological label?
OmitLabels = T

# Omit duplicated NBC Nightly News (ID=9) entries?
OmitNBC2 = T

# Omit ACLU data?
OmitACLU = F

# Number of Actual and Mega Think tanks
ActualThTaN = 44
MegaThTaN  = 6
# Number of Actual and Mega Think tanks 
#ActualThTaN = 30
#MegaThTaN  = 10
 

########################## Load Data ################################

##  You might need to edit the folder name that contains newscong.txt.  Or just make sure
##  it is in the folder called "C:/Documents and Settings/Tim/My Documents/Media.Bias.2004.08"
#xx <- read.table("C:/Documents and Settings/Tim/My Documents/Media.Bias.2004.08/newscong.txt",header=T)
##  On Desktop, do not capitalize "Tim"
#  xx <- read.table("C:/Documents and Settings/tim/My Documents/Media.Bias.2004.08/newscong.txt",header=T)

xx <- read.table("newscong.txt",header=T)
xx$DROPME <-  rep(0,nrow(xx))
#xx$DROPME[xx$ThTaID == 137 & xx$Year == 1995] <- 1
##xx$DROPME[xx$ThTaID == 17 & xx$Year == 2002] <- 1
xx <- xx[xx$DROPME == 0,]

NewsID   = xx$NewsID
NumDate  = xx$NumDate
AvReSc99 = xx$AvReSc99
Sents    = xx$Sents
ThTaID   = xx$ThTaID
Page1    = xx$Page1
Critic   = xx$Critic
Label    = xx$Label
CIdeo    = xx$CIdeo
Party    = xx$Party


# problematic TT 137 is the National Taxpayers Union
Omit137 = TRUE
if (Omit137) {
	print("Dropping TT 137")
  NumDate  = NumDate[ThTaID !=137]
  AvReSc99 = AvReSc99[ThTaID !=137]
  Sents    = Sents[ThTaID !=137]
  Page1    = Page1[ThTaID !=137]
  CIdeo    = CIdeo[ThTaID !=137]
  Party    = Party[ThTaID !=137]
  Critic   = Critic[ThTaID !=137] 
  Label    = Label[ThTaID !=137]
  NewsID   = NewsID[ThTaID !=137]
  ThTaID   = ThTaID[ThTaID !=137]
  ttN      = max(ThTaID)
  for (j in 138:ttN){
    ThTaID = ifelse(ThTaID==j,j-1,ThTaID)
  }
}

#  TT 17 is Brookings
Omit17 = FALSE
if (Omit17) {
	print("Dropping TT 17")
  NumDate  = NumDate[ThTaID !=17]
  AvReSc99 = AvReSc99[ThTaID !=17]
  Sents    = Sents[ThTaID !=17]
  Page1    = Page1[ThTaID !=17]
  CIdeo    = CIdeo[ThTaID !=17]
  Party    = Party[ThTaID !=17]
  Critic   = Critic[ThTaID !=17] 
  Label    = Label[ThTaID !=17]
  NewsID   = NewsID[ThTaID !=17]
  ThTaID   = ThTaID[ThTaID !=17]
  ttN      = max(ThTaID)
  for (j in 18:ttN){
    ThTaID = ifelse(ThTaID==j,j-1,ThTaID)
  }
}
#  TT 153 is Rand
Omit153 = FALSE
if (Omit153) {
	print("Dropping TT 153")
  NumDate  = NumDate[ThTaID !=153]
  AvReSc99 = AvReSc99[ThTaID !=153]
  Sents    = Sents[ThTaID !=153]
  Page1    = Page1[ThTaID !=153]
  CIdeo    = CIdeo[ThTaID !=153]
  Party    = Party[ThTaID !=153]
  Critic   = Critic[ThTaID !=153] 
  Label    = Label[ThTaID !=153]
  NewsID   = NewsID[ThTaID !=153]
  ThTaID   = ThTaID[ThTaID !=153]
  ttN      = max(ThTaID)
  for (j in 154:ttN){
    ThTaID = ifelse(ThTaID==j,j-1,ThTaID)
  }
}

#  TT 48 is Citizens Against Government Waste
Omit48 = FALSE
if (Omit48) {
	print("Dropping TT 48")
  NumDate  = NumDate[ThTaID !=48]
  AvReSc99 = AvReSc99[ThTaID !=48]
  Sents    = Sents[ThTaID !=48]
  Page1    = Page1[ThTaID !=48]
  CIdeo    = CIdeo[ThTaID !=48]
  Party    = Party[ThTaID !=48]
  Critic   = Critic[ThTaID !=48] 
  Label    = Label[ThTaID !=48]
  NewsID   = NewsID[ThTaID !=48]
  ThTaID   = ThTaID[ThTaID !=48]
  ttN      = max(ThTaID)
  for (j in 49:ttN){
    ThTaID = ifelse(ThTaID==j,j-1,ThTaID)
  }
}

####################### Create quality variables  ################################

TotalObs = length(NewsID)

print(TotalObs)



if (OmitCrits) {
  NewsID   = NewsID[Critic==0]
  NumDate  = NumDate[Critic==0]
  AvReSc99 = AvReSc99[Critic==0]
  Sents    = Sents[Critic==0]
  ThTaID   = ThTaID[Critic==0]
  Page1    = Page1[Critic==0]
  CIdeo    = CIdeo[Critic==0]
  Party    = Party[Critic==0]
  Label    = Label[Critic==0]
  Critic   = Critic[Critic==0]
}


if (OmitLabels) {
  NewsID   = NewsID[Label==0]
  NumDate  = NumDate[Label==0]
  AvReSc99 = AvReSc99[Label==0]
  Sents    = Sents[Label==0]
  ThTaID   = ThTaID[Label==0]
  Page1    = Page1[Label==0]
  CIdeo    = CIdeo[Label==0]
  Party    = Party[Label==0]
  Critic   = Critic[Label==0]  
  Label    = Label[Label==0]
}


if (OmitNBC2) {
  # enter 9's below to use the first set of NBC data
  # enter 8's to use the second set of NBC data. (and change 10 to 9)
  NumDate  = NumDate[NewsID !=9]
  AvReSc99 = AvReSc99[NewsID !=9]
  Sents    = Sents[NewsID !=9]
  ThTaID   = ThTaID[NewsID !=9]
  Page1    = Page1[NewsID !=9]
  CIdeo    = CIdeo[NewsID !=9]
  Party    = Party[NewsID !=9]
  Critic   = Critic[NewsID !=9] 
  Label    = Label[NewsID !=9]
  NewsID   = NewsID[NewsID !=9]
  for (j in 10:21){
    NewsID = ifelse(NewsID==j,j-1,NewsID)
  }
}

if (OmitACLU) {
  NumDate  = NumDate[ThTaID !=7]
  AvReSc99 = AvReSc99[ThTaID !=7]
  Sents    = Sents[ThTaID !=7]
  Page1    = Page1[ThTaID !=7]
  CIdeo    = CIdeo[ThTaID !=7]
  Party    = Party[ThTaID !=7]
  Critic   = Critic[ThTaID !=7] 
  Label    = Label[ThTaID !=7]
  NewsID   = NewsID[ThTaID !=7]
  ThTaID   = ThTaID[ThTaID !=7]
  ttN      = max(ThTaID)
  for (j in 8:ttN){
    ThTaID = ifelse(ThTaID==j,j-1,ThTaID)
  }
}


##########
# Use the following line to constrain NYT = NPR
#NewsID = ifelse(NewsID ==13, 10,NewsID)
#NewsID = ifelse(NewsID > 13, (NewsID-1), NewsID)

###### Caclulate Total number of Obs and total number of th tanks. ###
TotalObs     = length(NewsID)
ttN          = max(ThTaID)
TotalOutlets = max(NewsID)


####### Compute Ave. Sco. of legislators citing th. tank j ############
 
#for (j in 1:ttN) {
#  cong.cite.true = ifelse(xx$NewsID ==0 & xx$ThTaID == j,1,0)
#  cong.cite.sc <- ifelse(xx$NewsID ==0 & xx$ThTaID == j,xx$AvReSc99,0)
#  ttav[j]=sum(cong.cite.sc)/sum(cong.cite.true)
#}

getav = function(j){
  cong.cite.true = ifelse(NewsID ==0 & ThTaID == j,1,0)
  cong.cite.sc <- ifelse(NewsID ==0 & ThTaID == j,AvReSc99,0)
  ttavTem=sum(cong.cite.sc)/sum(cong.cite.true)
  ttavTem
}

pp = 1:ttN
ttav = sapply(pp, getav)

####### Compute number of cites by legislators to th tank j #############

getcongcites = function(j){
  cong.cite.true = ifelse(NewsID ==0 & ThTaID == j,1,0)
  ttcitesTem=sum(cong.cite.true)
  ttcitesTem
}

pp = 1:ttN
ttcongcites = sapply(pp, getcongcites)


####### Compute number of cites by media to th tank j #############

getmediacites = function(j){
  med.cite.true = ifelse(NewsID !=0  & ThTaID == j,1,0)
  ttcitesTem=sum(med.cite.true)
  ttcitesTem
}

pp = 1:ttN
ttmedcites = sapply(pp, getmediacites)


################# Print data for Table 1  ###########################

## Set OmitCrits, OmitLabels to T.  Set OmitACLU to F

print("Think Tank ID, Ave. Sco of legislator citing it, Cong Cites,  Media Cites")
print(cbind(1:ttN,ttav,ttcongcites,ttmedcites))



############# Compute Back of the Envelope Estimates  ################

## Create a vector that indicates if th tank is liberal  
LibThTa = rep(0,TotalObs)
for (j in 1:ttN) {
  LibThTa = ifelse(ThTaID == j & ttav[j] > CutPoint, 1, LibThTa)
}

## Create vectors that indicate if obs is by a Dem or Repub legislator
Dem = ifelse(NewsID==0 & Party == 1,1,0)
Rep = ifelse(NewsID==0 & Party == 2,1,0)
Cong = ifelse(NewsID==0,1,0)

## Creat vectors that indicate if obs is, e.g., a Dem citing a lib th tank
DemCiteLib = ifelse(NewsID==0 & Party == 1 & LibThTa == 1,1,0)
RepCiteLib = ifelse(NewsID==0 & Party == 2 & LibThTa == 1,1,0)
CongCiteLib = ifelse(NewsID==0 & LibThTa == 1,1,0)

## Create scalar = fraction of time that Dems cite lib th tanks
DemFrac  = sum(DemCiteLib)/sum(Dem)
RepFrac  = sum(RepCiteLib)/sum(Rep)
CongFrac = sum(CongCiteLib)/sum(Cong)


TotOutlets = max(NewsID)
MedFrac = rep(0,TotOutlets)

for (j in 1:TotOutlets){
  MedCiteTrue = ifelse(NewsID == j,1,0)
  MedCiteLib  = ifelse(NewsID == j & LibThTa == 1,1,0)
  MedFrac[j] = sum(MedCiteLib)/sum(MedCiteTrue)
}
  

## Create vector of Democratic Real scores. = 0 if not Dem (or a News Oulet)
DemScores  = ifelse(NewsID==0 & Party == 1,AvReSc99,0)
RepScores  = ifelse(NewsID==0 & Party == 2,AvReSc99,0)
CongScores = ifelse(NewsID==0,AvReSc99,0)


DemAve = sum(DemScores)/sum(Dem)
RepAve = sum(RepScores)/sum(Rep)
CongAve = sum(CongScores)/sum(Cong)

BOTE.Score = rep(0,TotOutlets)
for (j in 1:TotOutlets){
  BOTE.Score[j] = RepAve+(DemAve-RepAve)*(MedFrac[j]-RepFrac)/(DemFrac-RepFrac)
}

################### Print Descriptive Stats  ##############################

print("News Outlet ID, Frac of cites to lib th tanks, BOTE ADA score")
print(cbind(MedFrac,BOTE.Score))

print("Ave Scores of Repubs, Dems, and All members of Congress")
print(cbind(RepAve,CongAve,DemAve))

print("Frac of cites to lib th tanks by Repubs, Dems, and All members of Congress")
print(cbind(RepFrac,CongFrac,DemFrac))

print("Of all citations to all think tanks in Congress, Repubs had the following fraction")
RepFloorTime = sum(Rep)/sum(Cong)
print(RepFloorTime)



################################################################################
########################  Create NewThTaID #####################################
################################################################################

# 1 = Heritage, 2 = the most-cited think tank by the media
# ActualThTaN = the think tank ranked ActualThaN in terms of 
# cites by the media.  ActualThTaN + 1 = the most right-wing
# mega think tank.

#Using Congress
######### Create NewList and NewCites -- vectors of length ttN  ################
#NewCites    = rep(-1,ttN)
#NewCites[1] = ttcongcites[1]
#NewCites[2] = ttcongcites[2]
#
#NewList     = rep(0,ttN)
#NewList[1]  = 1
#NewList[2]  = 2
#
#for (i in 3:ttN){
#  FoundPlace = F
#  j = 2
#  AtEnd = F
#  while (FoundPlace == F) { 
#    if (ttcongcites[i] > NewCites[j]) 
#      {FoundPlace = T}
#    else {
#      j = j + 1
#      if (j == i) {
#        FoundPlace = T
#        AtEnd = T
#      }
#    }
#  }
#  if (AtEnd == T){
#    NewList[i] = i
#    NewCites[i] = ttcongcites[i] }
#  else {
#    k = i
#    while (k > j) {
#      NewList[k]  = NewList[k-1]
#      NewCites[k] = NewCites[k-1]
#      k = k - 1
#    }
#    NewList[j] = i
#    NewCites[j] = ttcongcites[i]
#  }
#}
#    

# Using Media
######### Create NewList and NewCites -- vectors of length ttN  ################

NewCites    = rep(-1,ttN)
NewCites[1] = ttmedcites[1]
NewCites[2] = ttmedcites[2]

NewList     = rep(0,ttN)
NewList[1]  = 1
NewList[2]  = 2

for (i in 3:ttN){
  FoundPlace = F
  j = 2
  AtEnd = F
  while (FoundPlace == F) { 
    if (ttmedcites[i] > NewCites[j]) 
      {FoundPlace = T}
    else {
      j = j + 1
      if (j == i) {
        FoundPlace = T
        AtEnd = T
      }
    }
  }
  if (AtEnd == T){
    NewList[i] = i
    NewCites[i] = ttmedcites[i] }
  else {
    k = i
    while (k > j) {
      NewList[k]  = NewList[k-1]
      NewCites[k] = NewCites[k-1]
      k = k - 1
    }
    NewList[j] = i
    NewCites[j] = ttmedcites[i]
  }
}
      

#### For Actual th tanks (not mega think tanks), create New Th tank ID ###

NewThTaID = rep(0,TotalObs)
for (i in 1:ActualThTaN){
  NewThTaID = ifelse(ThTaID == NewList[i],i,NewThTaID)
}

      
###### Compute Cut Points for Mega Think tanks  ##########
# Of the think tanks that are lumped into one of the Mega categories,
# the program computes the min ttav (ttav = the ave. score of legislators citing the 
# think tank) and the max ttav.  It then defines cut points to create 
# equal distances between the min and max ttav.  E.g. if the min ttav is 5, the
# max ttav is 85, and there are four mega think tanks, then the three cut points
# are 25, 45, and 65.

# Create starting values for min.ttav and max.ttav
min.ttav = ttav[ActualThTaN + 1]
max.ttav = ttav[ActualThTaN + 1]

for (i in (ActualThTaN+2):ttN){
  if (ttav[i] < min.ttav) { min.ttav = ttav[i] }
  if (ttav[i] > max.ttav) { max.ttav = ttav[i] }
}

MegaCutPoint = rep(0,MegaThTaN-1)
for (i in 1:(MegaThTaN - 1)){
  MegaCutPoint[i] = min.ttav + (i/MegaThTaN)*(max.ttav - min.ttav)
}


for (i in (ActualThTaN+1):ttN){
  FoundPlace = F
  j = 1
  while ((FoundPlace == F) & (j < MegaThTaN)){
    if (ttav[NewList[i]] < MegaCutPoint[j]){
      FoundPlace = T}
    else {
      j = j + 1
    }
  }
  # Now Think Tank NewList[i] belongs in MegaThTa j
  NewThTaID = ifelse(ThTaID == NewList[i],ActualThTaN+j,NewThTaID)
}


#########################################################################

### Compute new values for num. of cites and ttav (for mega th t's) #####

ttN = ActualThTaN + MegaThTaN

######## Compute Ave. Sco. of legislators citing th. tank j #############
 
new.getav = function(j){
  cong.cite.true = ifelse(NewsID ==0 & NewThTaID == j,1,0)
  cong.cite.sc <- ifelse(NewsID ==0 & NewThTaID == j,AvReSc99,0)
  ttavTem=sum(cong.cite.sc)/sum(cong.cite.true)
  ttavTem
}

pp = 1:ttN
new.ttav = sapply(pp, new.getav)

#### Compute number of cites by ALL (cong and media) to th tank j #######

get.all.cites = function(j){
  cite.true = ifelse(NewThTaID == j,1,0)
  ttcitesTem=sum(cite.true)
  ttcitesTem
}

pp = 1:ttN
tt.all.cites = sapply(pp, get.all.cites)









    
